@@ -1,6 +1,7 @@
 from cyberfusion.CoreApiClient import models
 
 from cyberfusion.CoreApiClient.interfaces import Resource
+from cyberfusion.CoreApiClient._helpers import construct_includes_query_parameter
 from cyberfusion.CoreApiClient.http import DtoResponse
 
 
@@ -24,6 +25,7 @@ class FTPUsers(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.FtpUsersSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.FTPUserResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -33,9 +35,8 @@ class FTPUsers(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.FTPUserResource)
@@ -44,9 +45,13 @@ class FTPUsers(Resource):
         self,
         *,
         id_: int,
+        includes: list[str] | None = None,
     ) -> DtoResponse[models.FTPUserResource]:
         local_response = self.api_connector.send_or_fail(
-            "GET", f"/api/v1/ftp-users/{id_}", data=None, query_parameters={}
+            "GET",
+            f"/api/v1/ftp-users/{id_}",
+            data=None,
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.FTPUserResource)
